summaryrefslogtreecommitdiff
path: root/src/include/taler_merchant_testing_lib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_merchant_testing_lib.h')
-rw-r--r--src/include/taler_merchant_testing_lib.h132
1 files changed, 66 insertions, 66 deletions
diff --git a/src/include/taler_merchant_testing_lib.h b/src/include/taler_merchant_testing_lib.h
index 4d00834d..abea85d4 100644
--- a/src/include/taler_merchant_testing_lib.h
+++ b/src/include/taler_merchant_testing_lib.h
@@ -1160,12 +1160,12 @@ TALER_TESTING_cmd_merchant_get_reserve (const char *label,
* @param reserve_reference reference to a "POST /reserves" that provides the
* information we are expecting.
* @param ... NULL-terminated list of labels (const char *) of
* tip (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
* @return the command.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_get_reserve_with_tips (const char *label,
+TALER_TESTING_cmd_merchant_get_reserve_with_rewards (const char *label,
const char *merchant_url,
unsigned int http_status,
const char *reserve_reference,
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
/**
* Define a get tips CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* server the /tip-query request.
* @param http_status expected HTTP response code for the
- * /tip-query request.
+ * /reward-query request.
* @param ... NULL-terminated list of labels (const char *) of
* tip (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_get_tips (const char *label,
+TALER_TESTING_cmd_get_rewards (const char *label,
const char *merchant_url,
unsigned int http_status,
...);
/**
* Define a get tips CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* server the /tip-query request.
* @param http_status expected HTTP response code for the
- * /tip-query request.
+ * /reward-query request.
* @param offset row to start querying the database from.
* @param limit how many rows to return (with direction).
* @param ... NULL-terminated list of labels (const char *) of
* tip (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_get_tips2 (const char *label,
+TALER_TESTING_cmd_get_rewards2 (const char *label,
const char *merchant_url,
uint64_t offset,
int64_t limit,
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
/**
- * Define a GET /private/tips/$TIP_ID CMD.
+ * Define a GET /private/rewards/$REWARD_ID CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* serve the request.
* @param tip_reference reference to a command that created a tip.
* @param http_status expected HTTP response code for the request.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_get_tip (const char *label,
+TALER_TESTING_cmd_merchant_get_reward (const char *label,
const char *merchant_url,
- const char *tip_reference,
+ const char *reward_reference,
unsigned int http_status);
/**
- * Define a GET /private/tips/$TIP_ID CMD.
+ * Define a GET /private/rewards/$REWARD_ID CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* serve the request.
* @param tip_reference reference to a command that created a tip.
* @param http_status expected HTTP response code for the request.
* @param ... NULL-terminated list of labels (const char *) of
* pickup (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_get_tip_with_pickups (const char *label,
+TALER_TESTING_cmd_merchant_get_reward_with_pickups (const char *label,
const char *merchant_url,
- const char *tip_reference,
+ const char *reward_reference,
unsigned int http_status,
...);
/**
- * Define a GET /tips/$TIP_ID CMD.
+ * Define a GET /rewards/$REWARD_ID CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* serve the request.
* @param tip_reference reference to a command that created a tip.
* @param http_status expected HTTP response code for the request.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_wallet_get_tip (const char *label,
+TALER_TESTING_cmd_wallet_get_reward (const char *label,
const char *merchant_url,
- const char *tip_reference,
+ const char *reward_reference,
unsigned int http_status);
/**
- * Define a GET /tips/$TIP_ID CMD.
+ * Define a GET /rewards/$REWARD_ID CMD.
*
* @param label the command label
* @param merchant_url base URL of the merchant which will
* serve the request.
* @param tip_reference reference to a command that created a tip.
* @param amount_remaining the balance remaining after pickups.
* @param http_status expected HTTP response code for the request.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_wallet_get_tip2 (const char *label,
+TALER_TESTING_cmd_wallet_get_reward2 (const char *label,
const char *merchant_url,
- const char *tip_reference,
+ const char *reward_reference,
const char *amount_remaining,
unsigned int http_status);
/**
- * Create a /tip-authorize CMD.
+ * Create a /reward-authorize CMD.
*
* @param label this command label
* @param merchant_url the base URL of the merchant that will
* serve the /tip-authorize request.
* @param exchange_url the base URL of the exchange that owns
* the reserve from which the tip is going to be gotten.
* @param http_status the HTTP response code which is expected
* for this operation.
* @param justification human-readable justification for this
* tip authorization.
* @param amount the amount to authorize for tipping.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_authorize (const char *label,
+TALER_TESTING_cmd_reward_authorize (const char *label,
const char *merchant_url,
const char *exchange_url,
unsigned int http_status,
@@ -1358,23 +1358,23 @@ TALER_TESTING_cmd_tip_authorize (const char *label,
/**
- * Create a /tip-authorize CMD.
+ * Create a /reward-authorize CMD.
*
* @param label this command label
* @param merchant_url the base URL of the merchant that will
* serve the /tip-authorize request.
* @param exchange_url the base URL of the exchange that owns
* the reserve from which the tip is going to be gotten.
* @param reserve_reference reference to a command that created
* a reserve.
* @param http_status the HTTP response code which is expected
* for this operation.
* @param justification human-readable justification for this
* tip authorization.
* @param amount the amount to authorize for tipping.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_authorize_from_reserve (const char *label,
+TALER_TESTING_cmd_reward_authorize_from_reserve (const char *label,
const char *merchant_url,
const char *exchange_url,
const char *reserve_reference,
@@ -1384,23 +1384,23 @@ TALER_TESTING_cmd_tip_authorize_from_reserve (const char *label,
/**
* Create a /tip-authorize CMD, specifying the Taler error code
* that is expected to be returned by the backend.
*
* @param label this command label
* @param merchant_url the base URL of the merchant that will
* serve the /tip-authorize request.
* @param exchange_url the base URL of the exchange that owns
* the reserve from which the tip is going to be gotten.
* @param http_status the HTTP response code which is expected
* for this operation.
* @param justification human-readable justification for this
* tip authorization.
* @param amount the amount to authorize for tipping.
* @param ec expected Taler-defined error code.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_authorize_with_ec (const char *label,
+TALER_TESTING_cmd_reward_authorize_with_ec (const char *label,
const char *merchant_url,
const char *exchange_url,
unsigned int http_status,
@@ -1410,25 +1410,25 @@ TALER_TESTING_cmd_tip_authorize_with_ec (const char *label,
/**
* Create a /tip-authorize CMD, specifying the Taler error code
* that is expected to be returned by the backend.
*
* @param label this command label
* @param merchant_url the base URL of the merchant that will
* serve the /tip-authorize request.
* @param exchange_url the base URL of the exchange that owns
* the reserve from which the tip is going to be gotten.
* @param reserve_reference reference to a command that created
* a reserve.
* @param http_status the HTTP response code which is expected
* for this operation.
* @param justification human-readable justification for this
* tip authorization.
* @param amount the amount to authorize for tipping.
* @param ec expected Taler-defined error code.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_authorize_from_reserve_with_ec (
+TALER_TESTING_cmd_reward_authorize_from_reserve_with_ec (
const char *label,
const char *merchant_url,
const char *exchange_url,
@@ -1449,26 +1449,26 @@ TALER_TESTING_cmd_tip_authorize_from_reserve_with_ec (
* @return the command.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_authorize_fake (const char *label);
+TALER_TESTING_cmd_reward_authorize_fake (const char *label);
/**
* Define a /tip-pickup CMD, equipped with the expected error
* code.
*
* @param label the command label
* @param merchant_url base URL of the backend which will serve
- * the /tip-pickup request.
+ * the /reward-pickup request.
* @param http_status expected HTTP response code.
* @param authorize_reference reference to a /tip-autorize CMD
* that offers a tip id to pick up.
* @param amounts array of string-defined amounts that specifies
- * which denominations will be accepted for tipping.
+ * which denominations will be accepted for rewardping.
* @param ec expected Taler error code.
* @return the command
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_pickup_with_ec (const char *label,
+TALER_TESTING_cmd_reward_pickup_with_ec (const char *label,
const char *merchant_url,
unsigned int http_status,
const char *authorize_reference,
@@ -1476,20 +1476,20 @@ TALER_TESTING_cmd_tip_pickup_with_ec (const char *label,
enum TALER_ErrorCode ec);
/**
- * Define a /tip-pickup CMD.
+ * Define a /reward-pickup CMD.
*
* @param label the command label
* @param merchant_url base URL of the backend which will serve
- * the /tip-pickup request.
+ * the /reward-pickup request.
* @param http_status expected HTTP response code.
* @param authorize_reference reference to a /tip-autorize CMD
* that offers a tip id to pick up.
* @param amounts array of string-defined amounts that specifies
- * which denominations will be accepted for tipping.
+ * which denominations will be accepted for rewardping.
* @return the command
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_tip_pickup (const char *label,
+TALER_TESTING_cmd_reward_pickup (const char *label,
const char *merchant_url,
unsigned int http_status,
const char *authorize_reference,
@@ -1889,7 +1889,7 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
// FIXME: rename: refund_entry->refund_detail
#define TALER_MERCHANT_TESTING_SIMPLE_TRAITS(op) \
op (claim_nonce, const struct GNUNET_CRYPTO_EddsaPublicKey) \
- op (tip_id, const struct TALER_TipIdentifierP) \
+ op (reward_id, const struct TALER_RewardIdentifierP) \
op (pickup_id, const struct TALER_PickupIdentifierP) \
op (instance_name, const char) \
op (instance_id, const char) \
@@ -1160,12 +1160,12 @@ TALER_TESTING_cmd_merchant_get_reserve (const char *label,
* information we are expecting.
* @param ... NULL-terminated list of labels (const char *) of
- * tip (commands) we expect to be returned in the list
+ * reward (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
* @return the command.
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
/**
- * Define a get tips CMD.
+ * Define a get rewards CMD.
*
* @param label the command label
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
* @param label the command label
* @param merchant_url base URL of the merchant which will
- * server the /tip-query request.
+ * server the /reward-query request.
* @param http_status expected HTTP response code for the
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
* @param ... NULL-terminated list of labels (const char *) of
- * tip (commands) we expect to be returned in the list
+ * reward (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
*/
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
...);
/**
- * Define a get tips CMD.
+ * Define a get rewards CMD.
*
* @param label the command label
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
* @param label the command label
* @param merchant_url base URL of the merchant which will
- * server the /tip-query request.
+ * server the /reward-query request.
* @param http_status expected HTTP response code for the
@@ -1224,40 +1224,40 @@ TALER_TESTING_cmd_merchant_purge_reserve (const char *label,
* @param limit how many rows to return (with direction).
* @param ... NULL-terminated list of labels (const char *) of
- * tip (commands) we expect to be returned in the list
+ * reward (commands) we expect to be returned in the list
* (assuming @a http_code is #MHD_HTTP_OK)
*/
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* @param merchant_url base URL of the merchant which will
* serve the request.
- * @param tip_reference reference to a command that created a tip.
+ * @param reward_reference reference to a command that created a reward.
* @param http_status expected HTTP response code for the request.
*/
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* @param merchant_url base URL of the merchant which will
* serve the request.
- * @param tip_reference reference to a command that created a tip.
+ * @param reward_reference reference to a command that created a reward.
* @param http_status expected HTTP response code for the request.
* @param ... NULL-terminated list of labels (const char *) of
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* @param merchant_url base URL of the merchant which will
* serve the request.
- * @param tip_reference reference to a command that created a tip.
+ * @param reward_reference reference to a command that created a reward.
* @param http_status expected HTTP response code for the request.
*/
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* @param merchant_url base URL of the merchant which will
* serve the request.
- * @param tip_reference reference to a command that created a tip.
+ * @param reward_reference reference to a command that created a reward.
* @param amount_remaining the balance remaining after pickups.
* @param http_status expected HTTP response code for the request.
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* @param label this command label
* @param merchant_url the base URL of the merchant that will
- * serve the /tip-authorize request.
+ * serve the /reward-authorize request.
* @param exchange_url the base URL of the exchange that owns
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* @param exchange_url the base URL of the exchange that owns
- * the reserve from which the tip is going to be gotten.
+ * the reserve from which the reward is going to be gotten.
* @param http_status the HTTP response code which is expected
* for this operation.
@@ -1266,90 +1266,90 @@ TALER_TESTING_cmd_get_tips2 (const char *label,
* for this operation.
* @param justification human-readable justification for this
- * tip authorization.
- * @param amount the amount to authorize for tipping.
+ * reward authorization.
+ * @param amount the amount to authorize for rewardping.
*/
struct TALER_TESTING_Command
@@ -1358,23 +1358,23 @@ TALER_TESTING_cmd_tip_authorize (const char *label,
* @param label this command label
* @param merchant_url the base URL of the merchant that will
- * serve the /tip-authorize request.
+ * serve the /reward-authorize request.
* @param exchange_url the base URL of the exchange that owns
@@ -1358,23 +1358,23 @@ TALER_TESTING_cmd_tip_authorize (const char *label,
* @param exchange_url the base URL of the exchange that owns
- * the reserve from which the tip is going to be gotten.
+ * the reserve from which the reward is going to be gotten.
* @param reserve_reference reference to a command that created
* a reserve.
@@ -1358,23 +1358,23 @@ TALER_TESTING_cmd_tip_authorize (const char *label,
* for this operation.
* @param justification human-readable justification for this
- * tip authorization.
- * @param amount the amount to authorize for tipping.
+ * reward authorization.
+ * @param amount the amount to authorize for rewardping.
*/
struct TALER_TESTING_Command
@@ -1384,23 +1384,23 @@ TALER_TESTING_cmd_tip_authorize_from_reserve (const char *label,
/**
- * Create a /tip-authorize CMD, specifying the Taler error code
+ * Create a /reward-authorize CMD, specifying the Taler error code
* that is expected to be returned by the backend.
*
@@ -1384,23 +1384,23 @@ TALER_TESTING_cmd_tip_authorize_from_reserve (const char *label,
* @param label this command label
* @param merchant_url the base URL of the merchant that will
- * serve the /tip-authorize request.
+ * serve the /reward-authorize request.
* @param exchange_url the base URL of the exchange that owns
@@ -1384,23 +1384,23 @@ TALER_TESTING_cmd_tip_authorize_from_reserve (const char *label,
* @param exchange_url the base URL of the exchange that owns
- * the reserve from which the tip is going to be gotten.
+ * the reserve from which the reward is going to be gotten.
* @param http_status the HTTP response code which is expected
* for this operation.
@@ -1384,23 +1384,23 @@ TALER_TESTING_cmd_tip_authorize_from_reserve (const char *label,
* for this operation.
* @param justification human-readable justification for this
- * tip authorization.
- * @param amount the amount to authorize for tipping.
+ * reward authorization.
+ * @param amount the amount to authorize for rewardping.
* @param ec expected Taler-defined error code.
*/
@@ -1410,25 +1410,25 @@ TALER_TESTING_cmd_tip_authorize_with_ec (const char *label,
/**
- * Create a /tip-authorize CMD, specifying the Taler error code
+ * Create a /reward-authorize CMD, specifying the Taler error code
* that is expected to be returned by the backend.
*
@@ -1410,25 +1410,25 @@ TALER_TESTING_cmd_tip_authorize_with_ec (const char *label,
* @param label this command label
* @param merchant_url the base URL of the merchant that will
- * serve the /tip-authorize request.
+ * serve the /reward-authorize request.
* @param exchange_url the base URL of the exchange that owns
@@ -1410,25 +1410,25 @@ TALER_TESTING_cmd_tip_authorize_with_ec (const char *label,
* @param exchange_url the base URL of the exchange that owns
- * the reserve from which the tip is going to be gotten.
+ * the reserve from which the reward is going to be gotten.
* @param reserve_reference reference to a command that created
* a reserve.
@@ -1410,25 +1410,25 @@ TALER_TESTING_cmd_tip_authorize_with_ec (const char *label,
* for this operation.
* @param justification human-readable justification for this
- * tip authorization.
- * @param amount the amount to authorize for tipping.
+ * reward authorization.
+ * @param amount the amount to authorize for rewardping.
* @param ec expected Taler-defined error code.
*/
@@ -1449,26 +1449,26 @@ TALER_TESTING_cmd_tip_authorize_from_reserve_with_ec (
/**
- * Define a /tip-pickup CMD, equipped with the expected error
+ * Define a /reward-pickup CMD, equipped with the expected error
* code.
*
@@ -1449,26 +1449,26 @@ TALER_TESTING_cmd_tip_authorize_from_reserve_with_ec (
* @param http_status expected HTTP response code.
- * @param authorize_reference reference to a /tip-autorize CMD
- * that offers a tip id to pick up.
+ * @param authorize_reference reference to a /reward-autorize CMD
+ * that offers a reward id to pick up.
* @param amounts array of string-defined amounts that specifies
@@ -1476,20 +1476,20 @@ TALER_TESTING_cmd_tip_pickup_with_ec (const char *label,
* @param http_status expected HTTP response code.
- * @param authorize_reference reference to a /tip-autorize CMD
- * that offers a tip id to pick up.
+ * @param authorize_reference reference to a /reward-autorize CMD
+ * that offers a reward id to pick up.
* @param amounts array of string-defined amounts that specifies